@@ -1,6 +1,6 @@
 # Additions to the SWIG-generated TeX__Kpathsea.pm
-# $Id: Kpathsea_add.pl,v 1.4 1999/07/13 08:47:58 jdg Exp $
-# CVS version tag name: $Name: upstream_version_3_3_1_9 $
+# $Id: Kpathsea_add.pl,v 1.5 2003/03/07 14:08:45 jdg Exp $
+# CVS version tag name: $Name: upstream_version_3_4_5_1 $
 #
 # Copyright 1999, Julian Gilbey <jdg@debian.org>
 # 
@@ -27,7 +27,7 @@ use Carp;
 # up-to-date.  There's a fallback default.  Use this ghastly mess so
 # that MakeMaker can extract a version number automatically.
 
-$VERSION = do { my @r=(q$Name: upstream_version_3_3_1_9 $=~/\d+/g); @r ? sprintf "%d."."%02d"x$#r,@r : 3.030101 };
+$VERSION = do { my @r=(q$Name: upstream_version_3_4_5_1 $=~/\d+/g); @r ? sprintf "%d."."%02d"x$#r,@r : 3.040501 };
 
 # We will deal with simple variables below; harder stuff first, though!
 
@@ -97,6 +97,9 @@ my (@exp_all_functions, @exp_all_short_functions);
     "kpse_web2c_format",
     "kpse_program_text_format",
     "kpse_program_binary_format",
+    "kpse_miscfonts_format",
+    "kpse_web_format",
+    "kpse_cweb_format",
 );
 
 @exp_all_functions = (
